@@ -81,24 +81,24 @@ class Pg:
         return contents
     
 
-    async def sort_not_column_fetchs(self, target, **opt):
+    async def sort_not_column_fetchs(self, target, opt='DESC',  **opts):
         "カラム無しのデータをソートして取得"
 
-        keys = list(opt.keys())
+        keys = list(opts.keys())
         limit = f"{keys[0]} = $1"
 
-        contents = await self.pool.fetch(f'SELECT * FROM {self.table} ORDER BY {target} DESC {limit}', *opt.values())
+        contents = await self.pool.fetch(f'SELECT * FROM {self.table} ORDER BY {target} {opt} {limit}', *opt.values())
         return contents
 
 
-    async def sort_fetchs(self, target, **opt):
+    async def sort_fetchs(self, target, opt='DESC', **opts):
         "データをソートして取得"
 
-        keys = list(opt.keys())
+        keys = tuple(opts.keys())
         column = f"{keys[0]} = $1"
         limit = f"{keys[1]} $2"
 
-        contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} ORDER BY {target} DESC {limit}', *opt.values())
+        contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} ORDER BY {target} {opt} {limit}', *opts.values())
         return contents
         
 
